Index: components/user_prefs/tracked/pref_hash_calculator.h |
diff --git a/components/user_prefs/tracked/pref_hash_calculator.h b/components/user_prefs/tracked/pref_hash_calculator.h |
index 1f9b74f0ad75ab5b61f6ac6a3a7b07a1afbf83d4..92b0c3a05d9d2e2d6d55dc18a598afa3c5d526d5 100644 |
--- a/components/user_prefs/tracked/pref_hash_calculator.h |
+++ b/components/user_prefs/tracked/pref_hash_calculator.h |
@@ -23,10 +23,13 @@ class PrefHashCalculator { |
VALID_SECURE_LEGACY, |
}; |
- // Constructs a PrefHashCalculator using |seed| and |device_id|. The same |
- // parameters must be used in order to successfully validate generated hashes. |
- // |device_id| may be empty. |
- PrefHashCalculator(const std::string& seed, const std::string& device_id); |
+ // Constructs a PrefHashCalculator using |seed|, |device_id| and |
+ // |legacy_device_id|. The same parameters must be used in order to |
+ // successfully validate generated hashes. |_device_id| or |legacy_device_id| |
+ // may be empty. |
+ PrefHashCalculator(const std::string& seed, |
+ const std::string& device_id, |
+ const std::string& legacy_device_id); |
~PrefHashCalculator(); |